==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/payment/ipayment_cc.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	ipayment_cc.lang.inc.php 2016-06-27
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'GM_CFG_AUTH' => 'auth',
	'GM_CFG_NORMAL' => 'normal',
	'GM_CFG_PREAUTH' => 'preauth',
	'GM_CFG_SILENT' => 'silent',
	'MODULE_PAYMENT_IPAYMENT_CC_ACCOUNT_ID_DESC' => 'Ihre Merchant ID',
	'MODULE_PAYMENT_IPAYMENT_CC_ACCOUNT_ID_TITLE' => 'Merchant ID',
	'MODULE_PAYMENT_IPAYMENT_CC_ADMINACTION_PASSWORD_DESC' => 'Ihr Adminaktionspasswort',
	'MODULE_PAYMENT_IPAYMENT_CC_ADMINACTION_PASSWORD_TITLE' => 'Adminaktionspasswort',
	'MODULE_PAYMENT_IPAYMENT_CC_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_IPAYMENT_CC_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_IPAYMENT_CC_APPLICATION_ID_DESC' => 'Ihre Merchant License',
	'MODULE_PAYMENT_IPAYMENT_CC_APPLICATION_ID_TITLE' => 'Merchant License',
	'MODULE_PAYMENT_IPAYMENT_CC_APPLICATION_PASSWORD_DESC' => 'Ihr Anwendungspasswort',
	'MODULE_PAYMENT_IPAYMENT_CC_APPLICATION_PASSWORD_TITLE' => 'Anwendungspasswort',
	'MODULE_PAYMENT_IPAYMENT_CC_AUTH_MODE_DESC' => 'Modus "auth": sofortige Zahlung, Modus "preauth": Verzögerte Zahlungsabwicklung',
	'MODULE_PAYMENT_IPAYMENT_CC_AUTH_MODE_TITLE' => 'Transaktionsmodus',
	'MODULE_PAYMENT_IPAYMENT_CC_ERRORORDER_STATUS_ID_DESC' => 'Bestellung im Fehlerfall auf diesen Status setzen',
	'MODULE_PAYMENT_IPAYMENT_CC_ERRORORDER_STATUS_ID_TITLE' => 'Fehlerstatus festlegen',
	'MODULE_PAYMENT_IPAYMENT_CC_MISSING' => 'FEHLT',
	'MODULE_PAYMENT_IPAYMENT_CC_OK' => 'OK',
	'MODULE_PAYMENT_IPAYMENT_CC_ORDER_STATUS_ID_DESC' => 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen',
	'MODULE_PAYMENT_IPAYMENT_CC_ORDER_STATUS_ID_TITLE' => 'Bestellstatus festlegen',
	'MODULE_PAYMENT_IPAYMENT_CC_PAYMENT_MODE_DESC' => 'Modus "normal": Weiterleitung zu ipayment, Modus "silent": Erfassung der Daten im Shop',
	'MODULE_PAYMENT_IPAYMENT_CC_PAYMENT_MODE_TITLE' => 'Zahlungsmodus',
	'MODULE_PAYMENT_IPAYMENT_CC_SANDBOX_DESC' => 'Sandbox-Modus (Testmodus) aktivieren',
	'MODULE_PAYMENT_IPAYMENT_CC_SANDBOX_TITLE' => 'Sandbox-Modus',
	'MODULE_PAYMENT_IPAYMENT_CC_SECURITY_KEY_DESC' => 'Ihr Security-Key',
	'MODULE_PAYMENT_IPAYMENT_CC_SECURITY_KEY_TITLE' => 'Security-Key',
	'MODULE_PAYMENT_IPAYMENT_CC_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_IPAYMENT_CC_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_IPAYMENT_CC_STATUS_DESC' => 'Möchten Sie Zahlungen via ipayment akzeptieren?',
	'MODULE_PAYMENT_IPAYMENT_CC_STATUS_TITLE' => 'ipayment-Zahlungsmodul aktivieren',
	'MODULE_PAYMENT_IPAYMENT_CC_SYSTEM_REQUIREMENTS' => 'Systemanforderungen',
	'MODULE_PAYMENT_IPAYMENT_CC_TEXT_DESCRIPTION' => '1&1 ipayment für Kreditkarten',
	'MODULE_PAYMENT_IPAYMENT_CC_TEXT_DESCRIPTION_LINK' => '<a target="_new" style="text-decoration: underline;" href="http://www.ipayment.de/">ipayment</a>',
	'MODULE_PAYMENT_IPAYMENT_CC_TEXT_INFO' => 'Zahlung mit Kreditkarte (Visa, MasterCard, Maestro, American Express, JCB, Diners Club, Visa Electron, Solo)',
	'MODULE_PAYMENT_IPAYMENT_CC_TEXT_TITLE' => '1&1 ipayment Kreditkarten',
	'MODULE_PAYMENT_IPAYMENT_CC_TMPORDER_STATUS_ID_DESC' => 'Bestellung während der Eingabe der Zahlungsdaten auf diesen Status setzen',
	'MODULE_PAYMENT_IPAYMENT_CC_TMPORDER_STATUS_ID_TITLE' => 'Temporären Bestellstatus festlegen',
	'MODULE_PAYMENT_IPAYMENT_CC_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_IPAYMENT_CC_ZONE_TITLE' => 'Zahlungszone',
	'MODULE_PAYMENT_IPAYMENT_CC_CARDS_ENABLED_TITLE' => 'Aktivierte Kreditkartentypen',
	'MODULE_PAYMENT_IPAYMENT_CC_CARDS_ENABLED_DESC' => 'Namen kommagetrennt eingeben, mögliche Werte: master,visa,amex,diners,jcb,solo,discover,maestro',
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/payment/ipayment_cc.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	ipayment_cc.lang.inc.php 2016-06-27
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'GM_CFG_AUTH' => 'auth',
	'GM_CFG_NORMAL' => 'normal',
	'GM_CFG_PREAUTH' => 'preauth',
	'GM_CFG_SILENT' => 'silent',
	'MODULE_PAYMENT_IPAYMENT_CC_ACCOUNT_ID_DESC' => 'Deine Merchant ID',
	'MODULE_PAYMENT_IPAYMENT_CC_ACCOUNT_ID_TITLE' => 'Merchant ID',
	'MODULE_PAYMENT_IPAYMENT_CC_ADMINACTION_PASSWORD_DESC' => 'Dein Adminaktionspasswort',
	'MODULE_PAYMENT_IPAYMENT_CC_ADMINACTION_PASSWORD_TITLE' => 'Adminaktionspasswort',
	'MODULE_PAYMENT_IPAYMENT_CC_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_IPAYMENT_CC_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_IPAYMENT_CC_APPLICATION_ID_DESC' => 'Deine Merchant License',
	'MODULE_PAYMENT_IPAYMENT_CC_APPLICATION_ID_TITLE' => 'Merchant License',
	'MODULE_PAYMENT_IPAYMENT_CC_APPLICATION_PASSWORD_DESC' => 'Dein Anwendungspasswort',
	'MODULE_PAYMENT_IPAYMENT_CC_APPLICATION_PASSWORD_TITLE' => 'Anwendungspasswort',
	'MODULE_PAYMENT_IPAYMENT_CC_AUTH_MODE_DESC' => 'Modus "auth": sofortige Zahlung, Modus "preauth": Verzögerte Zahlungsabwicklung',
	'MODULE_PAYMENT_IPAYMENT_CC_AUTH_MODE_TITLE' => 'Transaktionsmodus',
	'MODULE_PAYMENT_IPAYMENT_CC_ERRORORDER_STATUS_ID_DESC' => 'Bestellung im Fehlerfall auf diesen Status setzen',
	'MODULE_PAYMENT_IPAYMENT_CC_ERRORORDER_STATUS_ID_TITLE' => 'Fehlerstatus festlegen',
	'MODULE_PAYMENT_IPAYMENT_CC_MISSING' => 'FEHLT',
	'MODULE_PAYMENT_IPAYMENT_CC_OK' => 'OK',
	'MODULE_PAYMENT_IPAYMENT_CC_ORDER_STATUS_ID_DESC' => 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen',
	'MODULE_PAYMENT_IPAYMENT_CC_ORDER_STATUS_ID_TITLE' => 'Bestellstatus festlegen',
	'MODULE_PAYMENT_IPAYMENT_CC_PAYMENT_MODE_DESC' => 'Modus "normal": Weiterleitung zu ipayment, Modus "silent": Erfassung der Daten im Shop',
	'MODULE_PAYMENT_IPAYMENT_CC_PAYMENT_MODE_TITLE' => 'Zahlungsmodus',
	'MODULE_PAYMENT_IPAYMENT_CC_SANDBOX_DESC' => 'Sandbox-Modus (Testmodus) aktivieren',
	'MODULE_PAYMENT_IPAYMENT_CC_SANDBOX_TITLE' => 'Sandbox-Modus',
	'MODULE_PAYMENT_IPAYMENT_CC_SECURITY_KEY_DESC' => 'Dein Security-Key',
	'MODULE_PAYMENT_IPAYMENT_CC_SECURITY_KEY_TITLE' => 'Security-Key',
	'MODULE_PAYMENT_IPAYMENT_CC_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_IPAYMENT_CC_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_IPAYMENT_CC_STATUS_DESC' => 'Möchtest du Zahlungen via ipayment akzeptieren?',
	'MODULE_PAYMENT_IPAYMENT_CC_STATUS_TITLE' => 'ipayment-Zahlungsmodul aktivieren',
	'MODULE_PAYMENT_IPAYMENT_CC_SYSTEM_REQUIREMENTS' => 'Systemanforderungen',
	'MODULE_PAYMENT_IPAYMENT_CC_TEXT_DESCRIPTION' => '1&1 ipayment für Kreditkarten',
	'MODULE_PAYMENT_IPAYMENT_CC_TEXT_DESCRIPTION_LINK' => '<a target="_new" style="text-decoration: underline;" href="http://www.ipayment.de/">ipayment</a>',
	'MODULE_PAYMENT_IPAYMENT_CC_TEXT_INFO' => 'Zahlung mit Kreditkarte (Visa, MasterCard, Maestro, American Express, JCB, Diners Club, Visa Electron, Solo)',
	'MODULE_PAYMENT_IPAYMENT_CC_TEXT_TITLE' => '1&1 ipayment Kreditkarten',
	'MODULE_PAYMENT_IPAYMENT_CC_TMPORDER_STATUS_ID_DESC' => 'Bestellung während der Eingabe der Zahlungsdaten auf diesen Status setzen',
	'MODULE_PAYMENT_IPAYMENT_CC_TMPORDER_STATUS_ID_TITLE' => 'Temporären Bestellstatus festlegen',
	'MODULE_PAYMENT_IPAYMENT_CC_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_IPAYMENT_CC_ZONE_TITLE' => 'Zahlungszone',
	'MODULE_PAYMENT_IPAYMENT_CC_CARDS_ENABLED_TITLE' => 'Aktivierte Kreditkartentypen',
	'MODULE_PAYMENT_IPAYMENT_CC_CARDS_ENABLED_DESC' => 'Namen kommagetrennt eingeben, mögliche Werte: master,visa,amex,diners,jcb,solo,discover,maestro',
);
